package info.jbcs.minecraft.safe;

import java.util.ArrayList;

import net.minecraft.block.BlockContainer;
import net.minecraft.block.material.Material;
import net.minecraft.client.renderer.texture.IconRegister;
import net.minecraft.entity.EntityLivingBase;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.Icon;
import net.minecraft.util.MathHelper;
import net.minecraft.world.World;

public class BlockSafe extends BlockContainer {
	Icon iconSide,iconTop;
	
	public BlockSafe(int id) {
		super(id,Material.glass);	

		setStepSound(soundMetalFootstep);
		
		setHardness(0.3F);
		setResistance(6000000.0F);
		setBlockUnbreakable();
		
        setBlockBounds(0.0625F, 0.0F, 0.0625F, 0.9375F, 0.875F, 0.9375F);
	}

	@Override
	public boolean onBlockActivated(World world, int i, int j, int k, EntityPlayer entityplayer, int a, float b, float x, float y) {
		TileEntitySafe tileEntity = (TileEntitySafe) world.getBlockTileEntity(i, j, k);
		if (tileEntity == null)
			return false;

		int ox=i,oy=j,oz=k;
		int meta=world.getBlockMetadata(i, j, k);
		switch(meta){
		case 2: oz--; break;
		case 3: oz++; break;
		case 4: ox--; break;
		case 5: ox++; break;
		}
		
		if(! world.isAirBlock(ox, oy, oz))
			return true;
		
		if (entityplayer.username.equals(tileEntity.ownerName) || tileEntity.userCount>0 || entityplayer.capabilities.isCreativeMode) {
			Safe.guiSafe.open(entityplayer, world, i, j, k);
			
			return true;
		}
		
        world.playSoundEffect(i + 0.5D, j + 0.5D, k + 0.5D, "safe:safe-locked", 0.5F, world.rand.nextFloat() * 0.1F + 0.9F);
		return true;
	}

	@Override
	public void onBlockPlacedBy(World world, int i, int j, int k, EntityLivingBase entityliving, ItemStack stack) {
		TileEntitySafe e = new TileEntitySafe();

		if (entityliving instanceof EntityPlayer) {
			EntityPlayer player = (EntityPlayer) entityliving;
			e.ownerName = player.username;
		}

		if(stack.stackTagCompound!=null)
			e.readFromNBT(stack.stackTagCompound);

		world.setBlockTileEntity(i, j, k, e);
		
		byte meta = 0;
		int facing = MathHelper.floor_double((entityliving.rotationYaw * 4.0F / 360.0F) + 0.5D) & 3;

		if (facing == 0) {
			meta = 2;
		} else if (facing == 1) {
			meta = 5;
		} else if (facing == 2) {
			meta = 3;
		} else if (facing == 3) {
			meta = 4;
		}

		world.setBlockMetadataWithNotify(i, j, k, meta, 2);
	}
	
	@Override
	public void onBlockClicked(World world, int i, int j, int k, EntityPlayer entityplayer) {
		if(world.isRemote) return;
		
		TileEntitySafe tileEntity = (TileEntitySafe) world.getBlockTileEntity(i, j, k);
		if (tileEntity == null)
			return;
		
		if(entityplayer.username!=tileEntity.ownerName && !entityplayer.capabilities.isCreativeMode){
            world.playSoundEffect(i + 0.5D, j + 0.5D, k + 0.5D, "safe:safe-locked", 0.5F, world.rand.nextFloat() * 0.1F + 0.9F);
			return;
		}
		
		world.playAuxSFX(2001, i, j, k, blockID + (world.getBlockMetadata(i, j, k) << 12));
		dropBlockAsItem(world, i, j, k, world.getBlockMetadata(i, j, k), 0);
		world.setBlock(i, j, k, 0);
	}
	
	@Override
	public ArrayList<ItemStack> getBlockDropped(World world, int x, int y, int z, int metadata, int fortune) {
		ArrayList<ItemStack> ret = new ArrayList<ItemStack>();

		TileEntitySafe tileEntity = (TileEntitySafe) world.getBlockTileEntity(x, y, z);
		if (tileEntity == null)
			return ret;
		
		ItemStack stack=new ItemStack(blockID, 1, 0);
		stack.stackTagCompound=new NBTTagCompound();
		tileEntity.writeToNBT(stack.stackTagCompound);
		
		ret.add(stack);
		
		return ret;
	}



	@Override
	public int getRenderBlockPass() {
		return 0;
	}
	
    @Override
	public int getRenderType(){
        return BlockSafeRenderer.id;
    }

	@Override
	public TileEntity createNewTileEntity(World var1) {
		TileEntitySafe e=new TileEntitySafe();
		
		return e;
	}
	

	@Override
	public Icon getIcon(int side, int metadata) {
		return side<2?iconTop:iconSide;
	}

	@Override
	public void registerIcons(IconRegister register) {
		iconSide=register.registerIcon("safe:metal-side");
		iconTop=register.registerIcon("safe:metal-top");
	}

	@Override
	public boolean isOpaqueCube() {
		return false;
	}
}
